@@ -257,7 +257,7 @@ extern "C" {
     zeros(psi, J); 
     double *piProd = (double *) R_alloc(J, sizeof(double)); 
     ones(piProd, J); 
-    double *ySum = (double *) R_alloc(J, sizeof(double)); 
+    double *ySum = (double *) R_alloc(J, sizeof(double)); zeros(ySum, J);
 
     // For normal priors
     // Occupancy regression coefficient priors. 
